==> certmanager-model-v1alpha3-6.3.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/VaultAppRoleFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VaultAppRoleFluentImpl<A extends VaultAppRoleFluent<A>> extends BaseFluent<A> implements VaultAppRoleFluent<A>{
  public VaultAppRoleFluentImpl() {
  }
  public VaultAppRoleFluentImpl(VaultAppRole instance) {
    this.withPath(instance.getPath()); 
    this.withRoleId(instance.getRoleId()); 
    this.withSecretRef(instance.getSecretRef()); 
  }
  private String path;
  private String roleId;
  private SecretKeySelectorBuilder secretRef;
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getRoleId() {
    return this.roleId;
  }
  public A withRoleId(String roleId) {
    this.roleId=roleId; return (A) this;
  }
  public Boolean hasRoleId() {
    return this.roleId != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeySelector getSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public SecretKeySelector buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public A withSecretRef(SecretKeySelector secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new SecretKeySelectorBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  public Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(String key,String name) {
    return (A)withSecretRef(new SecretKeySelector(key, name));
  }
  public VaultAppRoleFluent.SecretRefNested<A> withNewSecretRef() {
    return new VaultAppRoleFluentImpl.SecretRefNestedImpl();
  }
  public VaultAppRoleFluent.SecretRefNested<A> withNewSecretRefLike(SecretKeySelector item) {
    return new VaultAppRoleFluentImpl.SecretRefNestedImpl(item);
  }
  public VaultAppRoleFluent.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public VaultAppRoleFluent.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new SecretKeySelectorBuilder().build());
  }
  public VaultAppRoleFluent.SecretRefNested<A> editOrNewSecretRefLike(SecretKeySelector item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VaultAppRoleFluentImpl that = (VaultAppRoleFluentImpl) o;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (roleId != null ? !roleId.equals(that.roleId) :that.roleId != null) return false;
    if (secretRef != null ? !secretRef.equals(that.secretRef) :that.secretRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  roleId,  secretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (roleId != null) { sb.append("roleId:"); sb.append(roleId + ","); }
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretRefNestedImpl<N> extends SecretKeySelectorFluentImpl<VaultAppRoleFluent.SecretRefNested<N>> implements VaultAppRoleFluent.SecretRefNested<N>,Nested<N>{
    SecretRefNestedImpl(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new SecretKeySelectorBuilder(this);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) VaultAppRoleFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/VaultAppRoleFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelector;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.meta.v1.SecretKeySelectorBuilder;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VaultAppRoleFluentImpl<A extends VaultAppRoleFluent<A>> extends BaseFluent<A> implements VaultAppRoleFluent<A>{
  public VaultAppRoleFluentImpl() {
  }
  public VaultAppRoleFluentImpl(VaultAppRole instance) {
    if (instance != null) {
      this.withPath(instance.getPath());
      this.withRoleId(instance.getRoleId());
      this.withSecretRef(instance.getSecretRef());
    }
  }
  private String path;
  private String roleId;
  private SecretKeySelectorBuilder secretRef;
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  public String getRoleId() {
    return this.roleId;
  }
  public A withRoleId(String roleId) {
    this.roleId=roleId; return (A) this;
  }
  public Boolean hasRoleId() {
    return this.roleId != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSecretRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretKeySelector getSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public SecretKeySelector buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public A withSecretRef(SecretKeySelector secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new SecretKeySelectorBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  public Boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(String key,String name) {
    return (A)withSecretRef(new SecretKeySelector(key, name));
  }
  public VaultAppRoleFluentImpl.SecretRefNested<A> withNewSecretRef() {
    return new VaultAppRoleFluentImpl.SecretRefNestedImpl();
  }
  public VaultAppRoleFluentImpl.SecretRefNested<A> withNewSecretRefLike(SecretKeySelector item) {
    return new VaultAppRoleFluentImpl.SecretRefNestedImpl(item);
  }
  public VaultAppRoleFluentImpl.SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(getSecretRef());
  }
  public VaultAppRoleFluentImpl.SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): new SecretKeySelectorBuilder().build());
  }
  public VaultAppRoleFluentImpl.SecretRefNested<A> editOrNewSecretRefLike(SecretKeySelector item) {
    return withNewSecretRefLike(getSecretRef() != null ? getSecretRef(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    VaultAppRoleFluentImpl that = (VaultAppRoleFluentImpl) o;
    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(roleId, that.roleId)) return false;

    if (!java.util.Objects.equals(secretRef, that.secretRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  roleId,  secretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (roleId != null) { sb.append("roleId:"); sb.append(roleId + ","); }
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  class SecretRefNestedImpl<N> extends SecretKeySelectorFluentImpl<VaultAppRoleFluentImpl.SecretRefNested<N>> implements VaultAppRoleFluentImpl.SecretRefNested<N>,Nested<N>{
    SecretRefNestedImpl(SecretKeySelector item) {
      this.builder = new SecretKeySelectorBuilder(this, item);
    }
    SecretRefNestedImpl() {
      this.builder = new SecretKeySelectorBuilder(this);
    }
    SecretKeySelectorBuilder builder;
    public N and() {
      return (N) VaultAppRoleFluentImpl.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}
